svn commit: r1612778 - in /openoffice/branches/AOO410: ./ main/ main/sw/ main/sw/source/core/txtnode/atrfld.cxx

2014-07-23 Thread orw
Author: orw
Date: Wed Jul 23 07:12:02 2014
New Revision: 1612778

URL: http://svn.apache.org/r1612778
Log:
125296: correction of fix for issue 125044

cherry-picked from trunk


Modified:
openoffice/branches/AOO410/   (props changed)
openoffice/branches/AOO410/main/   (props changed)
openoffice/branches/AOO410/main/sw/   (props changed)
openoffice/branches/AOO410/main/sw/source/core/txtnode/atrfld.cxx

Propchange: openoffice/branches/AOO410/
--
  Merged /openoffice/trunk:r1612539

Propchange: openoffice/branches/AOO410/main/
--
  Merged /openoffice/trunk/main:r1612539

Propchange: openoffice/branches/AOO410/main/sw/
--
  Merged /openoffice/trunk/main/sw:r1612539

Modified: openoffice/branches/AOO410/main/sw/source/core/txtnode/atrfld.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO410/main/sw/source/core/txtnode/atrfld.cxx?rev=1612778&r1=1612777&r2=1612778&view=diff
==
--- openoffice/branches/AOO410/main/sw/source/core/txtnode/atrfld.cxx (original)
+++ openoffice/branches/AOO410/main/sw/source/core/txtnode/atrfld.cxx Wed Jul 
23 07:12:02 2014
@@ -355,8 +355,7 @@ void SwTxtFld::ExpandTxtFld( const bool 
 const SwField* pFld = GetFmtFld().GetField();
 const XubString aNewExpand( 
pFld->ExpandField(m_pTxtNode->GetDoc()->IsClipBoard()) );
 
-if ( !bForceNotify &&
- aNewExpand == m_aExpand )
+if ( aNewExpand == m_aExpand )
 {
 // Bei Seitennummernfeldern
 const sal_uInt16 nWhich = pFld->GetTyp()->Which();
@@ -372,7 +371,11 @@ void SwTxtFld::ExpandTxtFld( const bool 
 {
 m_pTxtNode->ModifyNotification( 0, 0 );
 }
-return;
+if ( !bForceNotify )
+{
+// done, if no further notification forced.
+return;
+}
 }
 }
 




buildbot failure in ASF Buildbot on openoffice-fbsd-nightly

2014-07-23 Thread buildbot
The Buildbot has detected a failed build on builder openoffice-fbsd-nightly 
while building ASF Buildbot.
Full details are available at:
 http://ci.apache.org/builders/openoffice-fbsd-nightly/builds/76

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: bb-fbsd2_64bit

Build Reason: The Nightly scheduler named 'openoffice-fbsd-nightly' triggered 
this build
Build Source Stamp: [branch openoffice/trunk] HEAD
Blamelist: 

BUILD FAILED: failed

sincerely,
 -The Buildbot





svn commit: r1612782 - /openoffice/branches/AOO410/main/sw/source/core/unocore/unostyle.cxx

2014-07-23 Thread orw
Author: orw
Date: Wed Jul 23 07:25:52 2014
New Revision: 1612782

URL: http://svn.apache.org/r1612782
Log:
125299: bring back  which got accidently lost by merging changes for 
issue 78498 from trunk to branch AOO410


Modified:
openoffice/branches/AOO410/main/sw/source/core/unocore/unostyle.cxx

Modified: openoffice/branches/AOO410/main/sw/source/core/unocore/unostyle.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO410/main/sw/source/core/unocore/unostyle.cxx?rev=1612782&r1=1612781&r2=1612782&view=diff
==
--- openoffice/branches/AOO410/main/sw/source/core/unocore/unostyle.cxx 
(original)
+++ openoffice/branches/AOO410/main/sw/source/core/unocore/unostyle.cxx Wed Jul 
23 07:25:52 2014
@@ -1944,6 +1944,7 @@ void lcl_SetStyleProperty(const SfxItemP
 else
 throw lang::IllegalArgumentException();
 }
+break;
 
 case RES_PARATR_OUTLINELEVEL:
 {




buildbot success in ASF Buildbot on aoo-win7

2014-07-23 Thread buildbot
The Buildbot has detected a passing build on builder aoo-win7 while building 
ASF Buildbot.
Full details are available at:
 http://ci.apache.org/builders/aoo-win7/builds/98

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: bb-win7

Build Reason: The Nightly scheduler named 'aoo-win7-nightly' triggered this 
build
Build Source Stamp: [branch openoffice/branches/AOO410] HEAD
Blamelist: 

Build succeeded!

sincerely,
 -The Buildbot





svn commit: r1612785 - /openoffice/branches/AOO410/main/solenv/inc/minor.mk

2014-07-23 Thread jsc
Author: jsc
Date: Wed Jul 23 07:54:31 2014
New Revision: 1612785

URL: http://svn.apache.org/r1612785
Log:
#125084# adapt for rebuilt of m3

Modified:
openoffice/branches/AOO410/main/solenv/inc/minor.mk

Modified: openoffice/branches/AOO410/main/solenv/inc/minor.mk
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO410/main/solenv/inc/minor.mk?rev=1612785&r1=1612784&r2=1612785&view=diff
==
--- openoffice/branches/AOO410/main/solenv/inc/minor.mk (original)
+++ openoffice/branches/AOO410/main/solenv/inc/minor.mk Wed Jul 23 07:54:31 2014
@@ -19,7 +19,7 @@
 #
 # *
 RSCVERSION=411
-RSCREVISION=411m4(Build:9773)
+RSCREVISION=411m3(Build:9773)
 BUILD=9773
-LAST_MINOR=m4
+LAST_MINOR=m3
 SOURCEVERSION=AOO411




buildbot success in ASF Buildbot on openoffice-linux32-nightly

2014-07-23 Thread buildbot
The Buildbot has detected a passing build on builder openoffice-linux32-nightly 
while building ASF Buildbot.
Full details are available at:
 http://ci.apache.org/builders/openoffice-linux32-nightly/builds/94

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: bb-vm2_ubuntu_32bit

Build Reason: The Nightly scheduler named 'openoffice-linux32-nightly' 
triggered this build
Build Source Stamp: [branch openoffice/branches/AOO410] HEAD
Blamelist: 

Build succeeded!

sincerely,
 -The Buildbot





buildbot success in ASF Buildbot on openoffice-linux64-nightly

2014-07-23 Thread buildbot
The Buildbot has detected a passing build on builder openoffice-linux64-nightly 
while building ASF Buildbot.
Full details are available at:
 http://ci.apache.org/builders/openoffice-linux64-nightly/builds/88

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: tethys_ubuntu

Build Reason: The Nightly scheduler named 'openoffice-linux64-nightly' 
triggered this build
Build Source Stamp: [branch openoffice/trunk] HEAD
Blamelist: 

Build succeeded!

sincerely,
 -The Buildbot





svn commit: r1612801 - /openoffice/trunk/main/xmloff/source/draw/shapeexport2.cxx

2014-07-23 Thread orw
Author: orw
Date: Wed Jul 23 08:53:15 2014
New Revision: 1612801

URL: http://svn.apache.org/r1612801
Log:
125289: do apply possible changed  only for embedded images 
which already have its stream inside the package
fixes also issue 125290


Modified:
openoffice/trunk/main/xmloff/source/draw/shapeexport2.cxx

Modified: openoffice/trunk/main/xmloff/source/draw/shapeexport2.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmloff/source/draw/shapeexport2.cxx?rev=1612801&r1=1612800&r2=1612801&view=diff
==
--
  Merged /openoffice/trunk:r1612801

Propchange: openoffice/branches/AOO410/main/
--
  Merged /openoffice/trunk/main:r1612801

Modified: openoffice/branches/AOO410/main/xmloff/source/draw/shapeexport2.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO410/main/xmloff/source/draw/shapeexport2.cxx?rev=1612804&r1=1612803&r2=1612804&view=diff
==
--- openoffice/branches/AOO410/main/xmloff/source/draw/shapeexport2.cxx 
(original)
+++ openoffice/branches/AOO410/main/xmloff/source/draw/shapeexport2.cxx Wed Jul 
23 09:15:22 2014
@@ -1147,9 +1147,12 @@ void XMLShapeExport::ImpExportGraphicObj
 OUString aResolveURL( sImageURL );
 const rtl::OUString sPackageURL( RTL_CONSTASCII_USTRINGPARAM( 
"vnd.sun.star.Package:" ) );
 
-// sj: trying to preserve the filename
+// sj: trying to preserve the filename for embedded images 
which already have its stream inside the package
+bool bIsEmbeddedImageWithExistingStreamInPackage = false;
 if ( aStreamURL.match( sPackageURL, 0 ) )
 {
+bIsEmbeddedImageWithExistingStreamInPackage = true;
+
 rtl::OUString sRequestedName( aStreamURL.copy( 
sPackageURL.getLength(), aStreamURL.getLength() - sPackageURL.getLength() ) );
 sal_Int32 nLastIndex = sRequestedName.lastIndexOf( '/' ) + 
1;
 if ( ( nLastIndex > 0 ) && ( nLastIndex < 
sRequestedName.getLength() ) )
@@ -1169,21 +1172,24 @@ void XMLShapeExport::ImpExportGraphicObj
 
 if ( !aStr.isEmpty() )
 {
-aStreamURL = sPackageURL;
-if ( aStr[0] == '#' )
-{
-aStreamURL = aStreamURL.concat( aStr.copy( 1, 
aStr.getLength() - 1 ) );
-}
-else
+// apply possible changed stream URL to embedded image 
object
+if ( bIsEmbeddedImageWithExistingStreamInPackage )
 {
-aStreamURL = aStreamURL.concat( aStr );
+aStreamURL = sPackageURL;
+if ( aStr[0] == '#' )
+{
+aStreamURL = aStreamURL.concat( aStr.copy( 1, 
aStr.getLength() - 1 ) );
+}
+else
+{
+aStreamURL = aStreamURL.concat( aStr );
+}
+
+uno::Any aAny;
+aAny <<= aStreamURL;
+xPropSet->setPropertyValue( OUString( 
RTL_CONSTASCII_USTRINGPARAM( "GraphicStreamURL" ) ), aAny );
 }
 
-// update stream URL for load on demand
-uno::Any aAny;
-aAny <<= aStreamURL;
-xPropSet->setPropertyValue( OUString( 
RTL_CONSTASCII_USTRINGPARAM( "GraphicStreamURL" ) ), aAny );
-
 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_TYPE, 
XML_SIMPLE );
 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_SHOW, 
XML_EMBED );
 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_ACTUATE, 
XML_ONLOAD );




svn commit: r1612846 - in /openoffice/trunk/main/svgio/source/svgreader: svgnode.cxx svgtspannode.cxx

2014-07-23 Thread alg
Author: alg
Date: Wed Jul 23 15:09:02 2014
New Revision: 1612846

URL: http://svn.apache.org/r1612846
Log:
i125292, i125293 enhanced CssStyle handling in SVG import

Modified:
openoffice/trunk/main/svgio/source/svgreader/svgnode.cxx
openoffice/trunk/main/svgio/source/svgreader/svgtspannode.cxx

Modified: openoffice/trunk/main/svgio/source/svgreader/svgnode.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/svgio/source/svgreader/svgnode.cxx?rev=1612846&r1=1612845&r2=1612846&view=diff
==
--- openoffice/trunk/main/svgio/source/svgreader/svgnode.cxx (original)
+++ openoffice/trunk/main/svgio/source/svgreader/svgnode.cxx Wed Jul 23 
15:09:02 2014
@@ -55,6 +55,32 @@ namespace svgio
 
 if(rDocument.hasSvgStyleAttributesById())
 {
+// #125293# If we have CssStyles we need to buuild a 
linked list of SvgStyleAttributes
+// which represent this for the current object. There are 
various methods to
+// specify CssStyles which need to be taken into account 
in a given order:
+// - 'id' element
+// - 'class' element(s)
+// - type-dependent elements (e..g. 'rect' for all rect 
elements)
+// - local firect attributes (rOriginal)
+// - inherited attributes (up the hierarchy)
+// The first three will be collected in maCssStyleVector 
for the current element
+// (once, this will not change) and be linked in the 
needed order using the
+// get/setCssStyleParent at the SvgStyleAttributes which 
will be used preferred in
+// member evaluation over the existing parent hierarchy
+
+// check for 'id' references
+if(getId())
+{
+// search for CSS style equal to Id
+const SvgStyleAttributes* pNew = 
rDocument.findSvgStyleAttributesById(*getId());
+
+if(pNew)
+{
+const_cast< SvgNode* 
>(this)->maCssStyleVector.push_back(pNew);
+}
+}
+
+// check for 'class' references
 if(getClass())
 {
 // find all referenced CSS styles, a list of entries 
is allowed
@@ -64,52 +90,42 @@ namespace svgio
 const SvgStyleAttributes* pNew = 0;
 
 skip_char(*pClassList, sal_Unicode(' '), nPos, nLen);
-
+
 while(nPos < nLen)
 {
 rtl::OUStringBuffer aTokenValue;
-
+
 copyToLimiter(*pClassList, sal_Unicode(' '), nPos, 
aTokenValue, nLen);
 skip_char(*pClassList, sal_Unicode(' '), nPos, 
nLen);
 
 rtl::OUString 
aId(rtl::OUString::createFromAscii("."));
 const rtl::OUString 
aOUTokenValue(aTokenValue.makeStringAndClear());
-
+
 // look for CSS style common to token
 aId = aId + aOUTokenValue;
 pNew = rDocument.findSvgStyleAttributesById(aId);
-
+
 if(!pNew && rClassStr.getLength())
 {
 // look for CSS style common to class.token
 aId = rClassStr + aId;
-
+
 pNew = 
rDocument.findSvgStyleAttributesById(aId);
 }
-
+
 if(pNew)
 {
 const_cast< SvgNode* 
>(this)->maCssStyleVector.push_back(pNew);
 }
 }
 }
-
-if(maCssStyleVector.empty() && getId())
-{
-// if none found, search for CSS style equal to Id
-const SvgStyleAttributes* pNew = 
rDocument.findSvgStyleAttributesById(*getId());
-
-if(pNew)
-{
-const_cast< SvgNode* 
>(this)->maCssStyleVector.push_back(pNew);
-}
-}
 
-if(maCssStyleVector.empty() && rClassStr.getLength())
+// check for class-dependent references to CssStyles
+if(rClassStr.getLength())
 {
-// if none found, search for CSS style equal to class 
type
+// search for CSS style equal to class ty

svn commit: r1612866 - /openoffice/trunk/main/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx

2014-07-23 Thread alg
Author: alg
Date: Wed Jul 23 16:35:32 2014
New Revision: 1612866

URL: http://svn.apache.org/r1612866
Log:
125300 enhanced handling of multiple ClipRegions in MetafileProcessor

Modified:

openoffice/trunk/main/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx

Modified: 
openoffice/trunk/main/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx?rev=1612866&r1=1612865&r2=1612866&view=diff
==
--- 
openoffice/trunk/main/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx
 (original)
+++ 
openoffice/trunk/main/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx
 Wed Jul 23 16:35:32 2014
@@ -1741,20 +1741,55 @@ namespace drawinglayer
// prepare new mask 
polygon and rescue current one

aMask.transform(maCurrentTransformation);
 const basegfx::B2DPolyPolygon 
aLastClipPolyPolygon(maClipPolyPolygon);
-   
+
 if(maClipPolyPolygon.count())
 {
-   // there is 
already a clip polygon set; build clipped union of 
-   // current mask 
polygon and new one
-   
maClipPolyPolygon = basegfx::tools::clipPolyPolygonOnPolyPolygon(
-aMask, 
-maClipPolyPolygon, 
-true, // #i106516# we want the inside of 
aMask, not the outside
-false);
+// due to the cost of PolyPolygon clipping and 
numerical reasons try first if the current
+// and the new ClipRegion are ranges. If yes, 
processing can be simplified
+if(basegfx::tools::isRectangle(aMask) 
+&& 
basegfx::tools::isRectangle(maClipPolyPolygon))
+{
+// both ClipPolygons are rectangles
+
if(aMask.getB2DRange().equal(maClipPolyPolygon.getB2DRange()))
+{
+// equal -> no change in ClipRegion 
needed, leave
+// maClipPolyPolygon unchanged
+}
+else
+{
+// not equal -> create new ClipRegion 
from the two ranges
+basegfx::B2DRange 
aClipRange(aMask.getB2DRange());
+
+
aClipRange.intersect(maClipPolyPolygon.getB2DRange());
+
+if(aClipRange.isEmpty())
+{
+// no common ClipRegion -> set 
empty ClipRegion, no content to show
+maClipPolyPolygon.clear();
+}
+else
+{
+// use common ClipRegion as new 
ClipRegion
+maClipPolyPolygon = 
basegfx::B2DPolyPolygon(
+
basegfx::tools::createPolygonFromRect(aClipRange));
+}
+}
+}
+else
+{
+// The current ClipRegion or the new one 
is not a rectangle;
+// there is already a clip polygon set; 
build clipped union of 
+// current mask polygon and new one
+maClipPolyPolygon = 
basegfx::tools::clipPolyPolygonOnPolyPolygon(
+aMask, 
+maClipPolyPolygon, 
+true, // #i106516# we want the inside 
of aMask, not the outside
+false);
+}
 }
 else
 {
-// use mask directly
+// use new mask directly as ClipRegion
 maClipPolyPolygon = aMask;
  

svn commit: r1612927 - /openoffice/ooo-site/trunk/content/index_url.html

2014-07-23 Thread marcus
Author: marcus
Date: Wed Jul 23 19:25:03 2014
New Revision: 1612927

URL: http://svn.apache.org/r1612927
Log:
Testpage for URL redirecting

Added:
openoffice/ooo-site/trunk/content/index_url.html   (with props)

Added: openoffice/ooo-site/trunk/content/index_url.html
URL: 
http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/index_url.html?rev=1612927&view=auto
==
--- openoffice/ooo-site/trunk/content/index_url.html (added)
+++ openoffice/ooo-site/trunk/content/index_url.html Wed Jul 23 19:25:03 2014
@@ -0,0 +1,423 @@
+http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd";>
+http://www.w3.org/1999/xhtml"; />
+
+
+
+
+ 
+
+https://plus.google.com/+openoffice"; rel="publisher" />
+Apache OpenOffice - The Free and Open Productivity Suite
+
+
+
+
+
+/*  */
+
+
+  function follow( platform ) {
+_gaq.push( ['_trackEvent', 'social', 'followUs', platform] ); 
+
+if ( platform == 'ApacheBlog' ) {
+  window.open( "https://blogs.apache.org/OOo/";, "_blank" );
+} else if ( platform == 'Facebook' ) {
+  window.open( "https://www.facebook.com/ApacheOO";, "_blank" );
+} else if ( platform == 'Twitter' ) {
+  window.open( "https://twitter.com/ApacheOO";, "_blank" );
+} else if ( platform == 'GooglePlus' ) {
+  window.open( "https://plus.google.com/+openoffice";, "_blank" );
+}
+  }
+
+  function showAlertBox( show ) {
+   // More see "http://html-color-codes.info/";
+var l10n_index_alert_box_background_color  = "#F5A9A9";
+// Make the whole alert box clickable with a link.
+var l10n_index_alert_box_href  = "index.html";
+   // Maximum 49 characters.
+var l10n_index_alert_box_headline_text = "Headline text with 
max. 49 characters";
+   // Maximum 630 characters.
+var l10n_index_alert_box_text_text = "Text with max. 630 
characters."
+   + "

" + + "This alert box is now within the layout of the list items " + + "below.

" + + "The following link can be added to point the user to more " + + "information or to a solution. But the link can also be left " + + "out. Then the link will not be shown."; +// Show alert box or not? +if( show ) { + // If no background color value was set then use the default value. + if( ! l10n_index_alert_box_background_color ) +var l10n_index_alert_box_background_color = "#FFD9A7"; + + // Show alert box with defined background color. + // Depending if link is available, make the whole DIV clickable or not. + if( l10n_index_alert_box_href ) { +// Show the text with link and cursor as poiner. +document.write( "
" ); + +// Show headline. +document.write( "

" + l10n_index_alert_box_headline_text + "

" ); + +// Show text. +if( l10n_index_alert_box_text_text ) { + document.write( "

" + l10n_index_alert_box_text_text + "

" ); +} + } else { +// Show the text without link and normal cursor. +document.write( "
" ); + +// Show headline. +document.write( "

" + l10n_index_alert_box_headline_text + "

" ); + +// Show text. +if( l10n_index_alert_box_text_text ) { + document.write( "

" + l10n_index_alert_box_text_text + "

" ); +} + } + + document.write( "
" ); // Alert box +} + } + + function setRedirect() { + DL.NL_LANG = "";

svn commit: r917237 - in /websites/staging/ooo-site/trunk: cgi-bin/ content/ content/index_url.html

2014-07-23 Thread buildbot
Author: buildbot
Date: Wed Jul 23 19:26:59 2014
New Revision: 917237

Log:
Staging update by buildbot for ooo-site

Added:
websites/staging/ooo-site/trunk/content/index_url.html
Modified:
websites/staging/ooo-site/trunk/cgi-bin/   (props changed)
websites/staging/ooo-site/trunk/content/   (props changed)

Propchange: websites/staging/ooo-site/trunk/cgi-bin/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 19:26:59 2014
@@ -1 +1 @@
-1612774
+1612927

Propchange: websites/staging/ooo-site/trunk/content/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 19:26:59 2014
@@ -1 +1 @@
-1612774
+1612927

Added: websites/staging/ooo-site/trunk/content/index_url.html
==
--- websites/staging/ooo-site/trunk/content/index_url.html (added)
+++ websites/staging/ooo-site/trunk/content/index_url.html Wed Jul 23 19:26:59 
2014
@@ -0,0 +1,441 @@
+
+
+
+
+
+
+
+
+ 
+
+https://plus.google.com/+openoffice"; rel="publisher" />
+Apache OpenOffice - The Free and Open Productivity Suite
+
+
+
+
+
+/*  */
+
+
+  function follow( platform ) {
+_gaq.push( ['_trackEvent', 'social', 'followUs', platform] ); 
+
+if ( platform == 'ApacheBlog' ) {
+  window.open( "https://blogs.apache.org/OOo/";, "_blank" );
+} else if ( platform == 'Facebook' ) {
+  window.open( "https://www.facebook.com/ApacheOO";, "_blank" );
+} else if ( platform == 'Twitter' ) {
+  window.open( "https://twitter.com/ApacheOO";, "_blank" );
+} else if ( platform == 'GooglePlus' ) {
+  window.open( "https://plus.google.com/+openoffice";, "_blank" );
+}
+  }
+
+  function showAlertBox( show ) {
+   // More see "http://html-color-codes.info/";
+var l10n_index_alert_box_background_color  = "#F5A9A9";
+// Make the whole alert box clickable with a link.
+var l10n_index_alert_box_href  = "index.html";
+   // Maximum 49 characters.
+var l10n_index_alert_box_headline_text = "Headline text with 
max. 49 characters";
+   // Maximum 630 characters.
+var l10n_index_alert_box_text_text = "Text with max. 630 
characters."
+   + "

" + + "This alert box is now within the layout of the list items " + + "below.

" + + "The following link can be added to point the user to more " + + "information or to a solution. But the link can also be left " + + "out. Then the link will not be shown."; +// Show alert box or not? +if( show ) { + // If no background color value was set then use the default value. + if( ! l10n_index_alert_box_background_color ) +var l10n_index_alert_box_background_color = "#FFD9A7"; + + // Show alert box with defined background color. + // Depending if link is available, make the whole DIV clickable or not. + if( l10n_index_alert_box_href ) { +// Show the text with link and cursor as poiner. +document.write( "
" ); + +// Show headline. +document.write( "

" + l10n_index_alert_box_headline_text + "

" ); + +// Show text. +if( l10n_index_alert_box_text_text ) { + document.write( "

" + l10n_index_alert_box_text_text + "

" ); +} + } else { +// Show the text without link and normal cursor. +document.write( "
" ); + +// Show headline. +document.write( "


svn commit: r917241 - in /websites/staging/ooo-site/trunk: cgi-bin/ content/ content/index_url.html

2014-07-23 Thread buildbot
Author: buildbot
Date: Wed Jul 23 21:42:56 2014
New Revision: 917241

Log:
Staging update by buildbot for ooo-site

Modified:
websites/staging/ooo-site/trunk/cgi-bin/   (props changed)
websites/staging/ooo-site/trunk/content/   (props changed)
websites/staging/ooo-site/trunk/content/index_url.html

Propchange: websites/staging/ooo-site/trunk/cgi-bin/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 21:42:56 2014
@@ -1 +1 @@
-1612927
+1612952

Propchange: websites/staging/ooo-site/trunk/content/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 21:42:56 2014
@@ -1 +1 @@
-1612927
+1612952

Modified: websites/staging/ooo-site/trunk/content/index_url.html
==
--- websites/staging/ooo-site/trunk/content/index_url.html (original)
+++ websites/staging/ooo-site/trunk/content/index_url.html Wed Jul 23 21:42:56 
2014
@@ -90,44 +90,77 @@
   }
 
   function setRedirect() {
-   DL.NL_LANG  = "";   // Set to empty as both 
variables must not be used in following function.
-   DL.LANG_SEL = "";
-   var lang_iso= DL.getLanguage(); // Get the language ISO code 
from browser guessed data.
-   var lang_text   = "";   // The message text that can be 
shown.
-   var mode= "";   // Redirect mode.
-
+   DL.NL_LANG  = "";   // Set to empty 
as both variables ...
+   DL.LANG_SEL = "";   // ... must not 
be used in following function.
+   var lang_iso= DL.getLanguage(); // Get the 
language ISO code from browser guessed data.
+   var lang_mode   = "";   // Customized 
redirect mode.
+   var lang_text   = "";   // Customized 
message text that can be shown.
+   var link= "";   // Override 
redirect mode.
+/*
+   // Add ECMA262-5 Array methods if not supported natively.
+   // To workaround that MSIE 8 and older do not support this function.
+   if( !( 'indexOf' in Array.prototype ) ) {
+   Array.prototype.indexOf= function( find, i ) {  // 'i' is an 
optional parameter.
+   if( i === undefined ) {
+   i = 0;
+   }
+   if( i < 0 ) {
+   i+= this.length;
+   }
+   if( i < 0 ) {
+   i = 0;
+   }
+   for( var n = this.length; i < n; i++ ) {
+   if( i in this && this[ i ] === find ) {
+   return i;
+   }
+   }
+   return -1;
+   };
+   }
+*/
// Query if the browser language is one of the released languages.
// The array has 3 elements per language (defined in 
"/download/globalvars.js"
for( var i = 0, j = DL.SEL_LANG.length; i < j; i = i + 3 ) {
  // If the ISO code is found in the language array.
  if( DL.SEL_LANG[ i ] === lang_iso ) {
// Query for the redirect method (defined in "/msg_prop_l10n.js", 
column 0).
-   mode= l10n.index_redirect_text[ i / 3 * 2 ];
+   lang_mode   = l10n.index_redirect_text[ i / 3 * 2 ];
lang_text   = l10n.index_redirect_text[ i / 3 * 2 + 1 ];
break;
  }
}
 
-// alert( String( document.location ).indexOf( "soft" ) );
-   
+   alert( "ISO code: \t" + lang_iso+ "\n"
+  + "Mode:   \t\t" + lang_mode + "\n"
+  + "Text:   \t\t" + lang_text + "\n" );
+
+   // Convert the browser URL into a string.
+   link = String( document.location );
+
// Does the browser URL contain already a redirect mode?
-   if( String( document.location ).indexOf( "soft" ) != -1 ) {
-   // Set override mode to "soft".
-   mode = "soft";
-   } else if( String( document.location ).indexOf( "none" ) != -1 ) {
-   // Set override mode to "none".
-   mode = "none";
+   // If yes, set the new redirect mode to override the customized mode.
+   if( link.indexOf( "hard" ) !== -1 ) {
+   lang_mode = "hard";
+   } else if( link.indexOf( "soft" ) !== -1 ) {
+   lang_mode = "soft";
+   } else if( link.indexOf( "none" ) !== -1 ) {
+   lang_mode = "none";
}
 
-   switch( mode ) {
+   alert( "URL: \t\t" + document.location );
+
+   switch( lang_mode ) {
  case "hard":
// 

svn commit: r1612954 - /openoffice/ooo-site/trunk/content/index_url.html

2014-07-23 Thread marcus
Author: marcus
Date: Wed Jul 23 21:46:37 2014
New Revision: 1612954

URL: http://svn.apache.org/r1612954
Log:
Added debugging code

Modified:
openoffice/ooo-site/trunk/content/index_url.html

Modified: openoffice/ooo-site/trunk/content/index_url.html
URL: 
http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/index_url.html?rev=1612954&r1=1612953&r2=1612954&view=diff
==
--- openoffice/ooo-site/trunk/content/index_url.html (original)
+++ openoffice/ooo-site/trunk/content/index_url.html Wed Jul 23 21:46:37 2014
@@ -94,7 +94,7 @@
var lang_mode   = "";   // Customized 
redirect mode.
var lang_text   = "";   // Customized 
message text that can be shown.
var link= "";   // Override 
redirect mode.
-/*
+
// Add ECMA262-5 Array methods if not supported natively.
// To workaround that MSIE 8 and older do not support this function.
if( !( 'indexOf' in Array.prototype ) ) {
@@ -116,7 +116,7 @@
return -1;
};
}
-*/
+
// Query if the browser language is one of the released languages.
// The array has 3 elements per language (defined in 
"/download/globalvars.js"
for( var i = 0, j = DL.SEL_LANG.length; i < j; i = i + 3 ) {




svn commit: r917242 - in /websites/staging/ooo-site/trunk: cgi-bin/ content/ content/index_url.html

2014-07-23 Thread buildbot
Author: buildbot
Date: Wed Jul 23 21:47:09 2014
New Revision: 917242

Log:
Staging update by buildbot for ooo-site

Modified:
websites/staging/ooo-site/trunk/cgi-bin/   (props changed)
websites/staging/ooo-site/trunk/content/   (props changed)
websites/staging/ooo-site/trunk/content/index_url.html

Propchange: websites/staging/ooo-site/trunk/cgi-bin/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 21:47:09 2014
@@ -1 +1 @@
-1612952
+1612954

Propchange: websites/staging/ooo-site/trunk/content/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 21:47:09 2014
@@ -1 +1 @@
-1612952
+1612954

Modified: websites/staging/ooo-site/trunk/content/index_url.html
==
--- websites/staging/ooo-site/trunk/content/index_url.html (original)
+++ websites/staging/ooo-site/trunk/content/index_url.html Wed Jul 23 21:47:09 
2014
@@ -96,7 +96,7 @@
var lang_mode   = "";   // Customized 
redirect mode.
var lang_text   = "";   // Customized 
message text that can be shown.
var link= "";   // Override 
redirect mode.
-/*
+
// Add ECMA262-5 Array methods if not supported natively.
// To workaround that MSIE 8 and older do not support this function.
if( !( 'indexOf' in Array.prototype ) ) {
@@ -118,7 +118,7 @@
return -1;
};
}
-*/
+
// Query if the browser language is one of the released languages.
// The array has 3 elements per language (defined in 
"/download/globalvars.js"
for( var i = 0, j = DL.SEL_LANG.length; i < j; i = i + 3 ) {




svn commit: r1612967 - /openoffice/ooo-site/trunk/content/projects/native-lang.html.old

2014-07-23 Thread kschenk
Author: kschenk
Date: Wed Jul 23 23:09:53 2014
New Revision: 1612967

URL: http://svn.apache.org/r1612967
Log:
Adding backup copy of html versin of native-lang.html


Added:
openoffice/ooo-site/trunk/content/projects/native-lang.html.old
  - copied unchanged from r1612948, 
openoffice/ooo-site/trunk/content/projects/native-lang.html



svn commit: r917250 - in /websites/staging/ooo-site/trunk: cgi-bin/ content/ content/projects/native-lang.html.old

2014-07-23 Thread buildbot
Author: buildbot
Date: Wed Jul 23 23:11:30 2014
New Revision: 917250

Log:
Staging update by buildbot for ooo-site

Added:
websites/staging/ooo-site/trunk/content/projects/native-lang.html.old
Modified:
websites/staging/ooo-site/trunk/cgi-bin/   (props changed)
websites/staging/ooo-site/trunk/content/   (props changed)

Propchange: websites/staging/ooo-site/trunk/cgi-bin/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 23:11:30 2014
@@ -1 +1 @@
-1612954
+1612967

Propchange: websites/staging/ooo-site/trunk/content/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 23:11:30 2014
@@ -1 +1 @@
-1612954
+1612967

Added: websites/staging/ooo-site/trunk/content/projects/native-lang.html.old
==
--- websites/staging/ooo-site/trunk/content/projects/native-lang.html.old 
(added)
+++ websites/staging/ooo-site/trunk/content/projects/native-lang.html.old Wed 
Jul 23 23:11:30 2014
@@ -0,0 +1,551 @@
+
+
+
+OpenOffice in Native Languages
+  
+
+
+
+ 
+
+  Categories: Focus Areas , Incubator Areas, Native-Lang Confederation
+
+   
+
+   
+  
+  
+   OpenOffice in Native Languages
+  
+   The Native Language websites offer information, resources, and much more 
in a user's native language. 
+   Apache OpenOffice continues to welcome participation in a  variety of ways, 
as with
+   native language mailing lists and forums. Please visit the
+   http://openoffice.apache.org/native-lang.html";>Native Language 
Information area of the Apache OpenOffice project to find out more
+   about native language support specifically, and please see http://openoffice.apache.org/get-involved.html";>Getting Involved
+   for additional information on getting involved in Apache OpenOffice. 
+   
+   (http://www.openoffice.org/native-lang/";>Legacy information for 
the Native Language Confederation, not accurate for Apache OpenOffice.) 
+  
+  
+Note: The following list only includes languages that have their own 
website. For example, many of the African localizations are not listed. Please 
see:
+
+
+   http://www.openoffice.org/download/other.html";>The 
download page for a list of officially released languages
+   https://translate.apache.org/";>Pootle for an overview 
of the current localization status
+   http://svn.apache.org/viewvc/openoffice/";>The OpenOffice 
source code for a full list of available languages, including some that are 
not yet on Pootle
+   
+
+
+  In the following table:
+  
+  Level 1 means localization only or support only
+  Level 2 means localization, support, and other work 
+
+ 
+
+   
+  
+Language
+Level
+
+  
+   
+  
+Afar (aa)
+
+  Level 1*
+
+  
+
+
+  
+Albanian (sq)
+
+  Level 1*
+
+  
+
+  
+Afrikaans (af) 
+Level 1 
+
+  
+  
+Amharic (am) 
+Level 2 
+
+  
+  
+Arabic (ar)
+
+  Level 2*
+
+  
+
+  
+Armenian (hy)
+Level 1 
+
+  
+  
+Asturian (ast) 
+Level 1
+
+  
+  
+Azeri (az) 
+Level 2
+
+  
+  
+Balochi (bal) 
+Level 2 
+
+  
+  
+Basque (eu)
+Level 2 
+
+  
+  
+Bengali (bn)
+Level 1 
+
+  
+  
+Bosnian (bs) 
+Level 2 
+
+  
+  
+Breton (bre) 
+Level 1 
+
+  
+  
+Bulgarian (bg) 
+Level 1 
+
+  
+  
+Burmese (my) 
+Level 1 
+
+  
+  
+
+Catalan (ca)
+Level 2 
+
+  
+  
+ChiNyanja (NY)
+Level 2
+
+  
+  
+正體中文 Chinese (tw)
+Level 2 
+
+  
+  
+简体中文 Chinese (cn)
+Level 2 
+
+  
+  
+Czech (cs)
+Level 2 
+
+  
+  
+Croatian (hr)
+Level 1 
+
+  
+  
+Danish (da)
+Level 2 
+
+  
+  
+Dutch (nl)
+Level 2 
+
+  
+  
+Dzongkha (dz) 
+Level 2 
+
+  
+  
+Esperanto (eo) 
+Level 1 
+
+  
+  
+Estonian (et) 
+Level 2 
+
+  
+  
+Finnish (fi)
+Level 2 
+
+  
+  
+French (fr)
+Level 2 
+
+
+  
+  
+Friulian (fur) 
+Level 2 
+   
+  
+  
+Galician (gl) 
+Level 1 
+   
+  
+  
+Gaelic - Irish (ga) 
+Level 1 
+   
+  
+  
+Gaelic - Scottish (gd) 
+Level 1 
+   
+  
+  
+Georgian (ka) 
+Level 1 
+
+  
+  
+German (de)
+Level 2 
+   
+  
+  
+Greek (el)
+Level 2 
+   
+  
+  
+Gujarati (gu)
+Level 1 
+   
+  
+  
+Haitian Creole (ht)
+Level 1 
+   
+  
+  
+
+
+  
+Hebrew (he)
+Level 2 
+  
+  
+  
+Hindi (hi)
+Level 2 
+   
+  
+  
+Hungarian (hu)
+Level 2 
+   
+  
+  
+Icelandic (is)
+Level 2
+   
+  
+  

svn commit: r1612968 - /openoffice/ooo-site/trunk/content/projects/native-lang.mdtext

2014-07-23 Thread kschenk
Author: kschenk
Date: Wed Jul 23 23:13:03 2014
New Revision: 1612968

URL: http://svn.apache.org/r1612968
Log:
Deleted native-lang.html and added native-lang.mdtext
Patch submitted by: Emanuele


Added:
openoffice/ooo-site/trunk/content/projects/native-lang.mdtext

Added: openoffice/ooo-site/trunk/content/projects/native-lang.mdtext
URL: 
http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/projects/native-lang.mdtext?rev=1612968&view=auto
==
--- openoffice/ooo-site/trunk/content/projects/native-lang.mdtext (added)
+++ openoffice/ooo-site/trunk/content/projects/native-lang.mdtext Wed Jul 23 
23:13:03 2014
@@ -0,0 +1,140 @@
+Title:  OpenOffice in Native Languages
+Notice:Licensed to the Apache Software Foundation (ASF) under one
+   or more contributor license agreements.  See the NOTICE file
+   distributed with this work for additional information
+   regarding copyright ownership.  The ASF licenses this file
+   to you under the Apache License, Version 2.0 (the
+   "License"); you may not use this file except in compliance
+   with the License.  You may obtain a copy of the License at
+   .
+ http://www.apache.org/licenses/LICENSE-2.0
+   .
+   Unless required by applicable law or agreed to in writing,
+   software distributed under the License is distributed on an
+   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+   KIND, either express or implied.  See the License for the
+   specific language governing permissions and limitations
+   under the License.
+
+
+## [![native language globe](/branding/images/language.png)] OpenOffice in 
Native Languages
+
+
+The Native Language websites offer information, resources, and much more in a 
user's native language.
+
+Apache OpenOffice continues to welcome participation in a  variety of ways, as 
with native language mailing lists and forums. Please visit the [Native 
Language Information](http://openoffice.apache.org/native-lang.html) area of 
the Apache OpenOffice project to find out more about native language support 
specifically, and please see [Getting 
Involved](http://openoffice.apache.org/get-involved.html) for additional 
information on getting involved in Apache OpenOffice.
+
+([Legacy information for the Native Language Confederation](/native-lang/), 
not accurate for Apache OpenOffice.)
+
+
+Note: The following list only includes languages that have their own website. 
For example, many of the African localizations are not listed. Please see:
+
+  - [The download page](/download/other.html) for a list of officially 
released languages
+  - [Pootle](https://translate.apache.org/) for an overview of the current 
localization status
+  - [The OpenOffice source code](http://svn.apache.org/viewvc/openoffice/) for 
a full list of available languages, including some that are not yet on Pootle
+  
+  In the following table, the defintions for "Status" are:
+  
+  - "under construction": the web site has minimal content, and the status of 
an OpenOffice distribution in this language is unknown
+  - "outdated": the web site is out of date and is likely due to no current 
version (>3.3) of Apache OpenOffice in this language. To help release new 
versions of Apache OpenOffice in these languages, please see the project 
+  [Native Language page](http://openoffice.apache.org/native-lang.html). 
+  - "unmaintatined (help needed)": the web site is not actively maintained but 
there is a current version for this language
+  - "unmaintained": this web site is not maintained and the distribution 
status in this language is unknown
+
+
+ Language  | Status
+-- | 
+[Afar (aa)](/aa/)   | under construction
+[Albanian (sq)](/sq/) |  outdated (1.x)
+[Afrikaans (af)](/af/) | outdated
+[Amharic (am) ](/am/)  | under construction
+[Arabic (ar)](/ar/) |  outdated (3.4)
+[Armenian (hy)](/hy/) |  outdated (1.x)
+[Asturian (ast) ](/ast/) |  maintained
+[Azeri (az) ](/az/) | outdated
+[Balochi (bal)](/bal/) |  under construction
+[Basque (eu)](/eu/) | unmaintatined (help needed)
+[Bengali (bn)](/bn/) | outdated (2.x)
+[Bosnian (bs) ](/bs/) |  outdated (1.x)
+[Breton (bre)](/bre/) | outdated (2.x)
+[Bulgarian (bg) ](/bg/) | unmaintatined (help needed)
+[Burmese (my) ](/my/) | maintained
+[Catalan (ca)](/ca/) | unmaintained (help needed)
+[ChiNyanja (NY)](/ny/) | under construction
+[正體中文 Chinese (tw)](/zh-tw/) | maintained
+[简体中文 Chinese (cn)](/zh-cn/) | maintained
+[Czech (cs)](/cs/) | maintained
+[Croatian (hr)](/hr/) | unmaintained (help needed)
+[Danish (da)](/da/) | unmaintained (help needed)
+[Dutch (nl)](/nl/) | maintained
+[Dzongkha (dz) ](/dz/) | under construction
+[Esperanto (eo)](/eo/) | unmaintained
+[Estonian (et) ](/et/) | unmaintained (help needed)
+[Finnish (

svn commit: r917251 - in /websites/staging/ooo-site/trunk: cgi-bin/ content/ content/projects/native-lang.html

2014-07-23 Thread buildbot
Author: buildbot
Date: Wed Jul 23 23:14:27 2014
New Revision: 917251

Log:
Staging update by buildbot for ooo-site

Modified:
websites/staging/ooo-site/trunk/cgi-bin/   (props changed)
websites/staging/ooo-site/trunk/content/   (props changed)
websites/staging/ooo-site/trunk/content/projects/native-lang.html

Propchange: websites/staging/ooo-site/trunk/cgi-bin/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 23:14:27 2014
@@ -1 +1 @@
-1612967
+1612968

Propchange: websites/staging/ooo-site/trunk/content/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 23:14:27 2014
@@ -1 +1 @@
-1612967
+1612968

Modified: websites/staging/ooo-site/trunk/content/projects/native-lang.html
==
--- websites/staging/ooo-site/trunk/content/projects/native-lang.html (original)
+++ websites/staging/ooo-site/trunk/content/projects/native-lang.html Wed Jul 
23 23:14:27 2014
@@ -3,15 +3,10 @@
 
 
 
-
 OpenOffice in Native Languages
-  
+
 
 
-
- 
  
 
 
@@ -26,546 +21,416 @@
   
   
 
-
-
-  Categories: Focus Areas , Incubator Areas, Native-Lang Confederation
-
-   
-
-   
-  
-  
-   OpenOffice in Native Languages
-  
-   The Native Language websites offer information, resources, and much more 
in a user's native language. 
-   Apache OpenOffice continues to welcome participation in a  variety of ways, 
as with
-   native language mailing lists and forums. Please visit the
-   http://openoffice.apache.org/native-lang.html";>Native Language 
Information area of the Apache OpenOffice project to find out more
-   about native language support specifically, and please see http://openoffice.apache.org/get-involved.html";>Getting Involved
-   for additional information on getting involved in Apache OpenOffice. 
-   
-   (http://www.openoffice.org/native-lang/";>Legacy information for 
the Native Language Confederation, not accurate for Apache OpenOffice.) 
-  
-  
-Note: The following list only includes languages that have their own 
website. For example, many of the African localizations are not listed. Please 
see:
-
-
-   http://www.openoffice.org/download/other.html";>The 
download page for a list of officially released languages
-   https://translate.apache.org/";>Pootle for an overview 
of the current localization status
-   http://svn.apache.org/viewvc/openoffice/";>The OpenOffice 
source code for a full list of available languages, including some that are 
not yet on Pootle
-   
-
-
-  In the following table:
-  
-  Level 1 means localization only or support only
-  Level 2 means localization, support, and other work 
+OpenOffice in Native Languages
+[] OpenOffice in Native Languages
+
+The Native Language websites offer information, resources, and much more in a 
user's native language.
+
+Apache OpenOffice continues to welcome participation in a  variety of ways, as 
with native language mailing lists and forums. Please visit the [Native 
Language Information](http://openoffice.apache.org/native-lang.html) area of 
the Apache OpenOffice project to find out more about native language support 
specifically, and please see [Getting 
Involved](http://openoffice.apache.org/get-involved.html) for additional 
information on getting involved in Apache OpenOffice.
+
+([Legacy information for the Native Language Confederation](/native-lang/), 
not accurate for Apache OpenOffice.)
+
+
+Note: The following list only includes languages that have their own 
website. For example, many of the African localizations are not listed. Please 
see:
+
+The download page for a list of 
officially released languages
+https://translate.apache.org/";>Pootle for an overview of the 
current localization status
+http://svn.apache.org/viewvc/openoffice/";>The OpenOffice source 
code for a full list of available languages, including some that are not 
yet on Pootle
 
- 
-
-   
-  
-Language
-Level
-
-  
-   
-  
-Afar (aa)
-
-  Level 1*
-
-  
-
-
-  
-Albanian (sq)
-
-  Level 1*
-
-  
-
-  
-Afrikaans (af) 
-Level 1 
-
-  
-  
-Amharic (am) 
-Level 2 
-
-  
-  
-Arabic (ar)
-
-  Level 2*
-
-  
-
-  
-Armenian (hy)
-Level 1 
-
-  
-  
-Asturian (ast) 
-Level 1
-
-  
-  
-Azeri (az) 
-Level 2
-
-  
-  
-Balochi (bal) 
-Level 2 
-
-  
-  
-Basque (eu)
-Level 2 
-
-  
-  
-Bengali (bn)
-Level 1 
-
-  
-  
-Bosnian (bs) 
-Level 2 
-
-  
-  
-Breton (bre) 
-Level 1 
-
-  
-  
-Bulgarian (bg) 
-Level 1 
-
-  
-  
-Burmese (my) 
- 

svn commit: r1612970 - /openoffice/ooo-site/trunk/content/projects/native-lang.mdtext

2014-07-23 Thread kschenk
Author: kschenk
Date: Wed Jul 23 23:18:56 2014
New Revision: 1612970

URL: http://svn.apache.org/r1612970
Log:
Fixed the first tag containing the image.


Modified:
openoffice/ooo-site/trunk/content/projects/native-lang.mdtext

Modified: openoffice/ooo-site/trunk/content/projects/native-lang.mdtext
URL: 
http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/projects/native-lang.mdtext?rev=1612970&r1=1612969&r2=1612970&view=diff
==
--- openoffice/ooo-site/trunk/content/projects/native-lang.mdtext (original)
+++ openoffice/ooo-site/trunk/content/projects/native-lang.mdtext Wed Jul 23 
23:18:56 2014
@@ -17,7 +17,7 @@ Notice:Licensed to the Apache Softwa
under the License.
 
 
-## [![native language globe](/branding/images/language.png)] OpenOffice in 
Native Languages
+## ![native language globe](/branding/images/language.png) OpenOffice in 
Native Languages
 
 
 The Native Language websites offer information, resources, and much more in a 
user's native language.




svn commit: r917252 - in /websites/staging/ooo-site/trunk: cgi-bin/ content/ content/projects/native-lang.html

2014-07-23 Thread buildbot
Author: buildbot
Date: Wed Jul 23 23:20:33 2014
New Revision: 917252

Log:
Staging update by buildbot for ooo-site

Modified:
websites/staging/ooo-site/trunk/cgi-bin/   (props changed)
websites/staging/ooo-site/trunk/content/   (props changed)
websites/staging/ooo-site/trunk/content/projects/native-lang.html

Propchange: websites/staging/ooo-site/trunk/cgi-bin/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 23:20:33 2014
@@ -1 +1 @@
-1612968
+1612970

Propchange: websites/staging/ooo-site/trunk/content/
--
--- cms:source-revision (original)
+++ cms:source-revision Wed Jul 23 23:20:33 2014
@@ -1 +1 @@
-1612968
+1612970

Modified: websites/staging/ooo-site/trunk/content/projects/native-lang.html
==
--- websites/staging/ooo-site/trunk/content/projects/native-lang.html (original)
+++ websites/staging/ooo-site/trunk/content/projects/native-lang.html Wed Jul 
23 23:20:33 2014
@@ -22,7 +22,7 @@
   
 
 OpenOffice in Native Languages
-[] OpenOffice in Native Languages
+ OpenOffice in Native Languages
 
 The Native Language websites offer information, resources, and much more in a 
user's native language.
 




buildbot failure in ASF Buildbot on openoffice-linux32-nightly

2014-07-23 Thread buildbot
The Buildbot has detected a failed build on builder openoffice-linux32-nightly 
while building ASF Buildbot.
Full details are available at:
 http://ci.apache.org/builders/openoffice-linux32-nightly/builds/95

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: bb-vm2_ubuntu_32bit

Build Reason: The Nightly scheduler named 'openoffice-linux32-nightly' 
triggered this build
Build Source Stamp: [branch openoffice/branches/AOO410] HEAD
Blamelist: 

BUILD FAILED: failed

sincerely,
 -The Buildbot





buildbot failure in ASF Buildbot on openoffice-fbsd-nightly

2014-07-23 Thread buildbot
The Buildbot has detected a failed build on builder openoffice-fbsd-nightly 
while building ASF Buildbot.
Full details are available at:
 http://ci.apache.org/builders/openoffice-fbsd-nightly/builds/77

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: bb-fbsd2_64bit

Build Reason: The Nightly scheduler named 'openoffice-fbsd-nightly' triggered 
this build
Build Source Stamp: [branch openoffice/trunk] HEAD
Blamelist: 

BUILD FAILED: failed

sincerely,
 -The Buildbot
--- openoffice/trunk/main/xmloff/source/draw/shapeexport2.cxx (original)
+++ openoffice/trunk/main/xmloff/source/draw/shapeexport2.cxx Wed Jul 23 
08:53:15 2014
@@ -1147,9 +1147,12 @@ void XMLShapeExport::ImpExportGraphicObj
 OUString aResolveURL( sImageURL );
 const rtl::OUString sPackageURL( RTL_CONSTASCII_USTRINGPARAM( 
"vnd.sun.star.Package:" ) );
 
 // sj: trying to preserve the filename
which already have its stream inside the package
+bool bIsEmbeddedImageWithExistingStreamInPackage = false;
 if ( aStreamURL.match( sPackageURL, 0 ) )
 {
+bIsEmbeddedImageWithExistingStreamInPackage = true;
+
 rtl::OUString sRequestedName( aStreamURL.copy( 
sPackageURL.getLength(), aStreamURL.getLength() - sPackageURL.getLength() ) );
 sal_Int32 nLastIndex = sRequestedName.lastIndexOf( '/' ) + 
1;
 if ( ( nLastIndex > 0 ) && ( nLastIndex < 
sRequestedName.getLength() ) )
@@ -1169,21 +1172,24 @@ void XMLShapeExport::ImpExportGraphicObj
 
 if ( !aStr.isEmpty() )
 {
-aStreamURL = sPackageURL;
-if ( aStr[0] == '#' )
-{
-aStreamURL = aStreamURL.concat( aStr.copy( 1, 
aStr.getLength() - 1 ) );
-}
-else
+// apply possible changed stream URL to embedded image 
object
+if ( bIsEmbeddedImageWithExistingStreamInPackage )
 {
-aStreamURL = aStreamURL.concat( aStr );
+aStreamURL = sPackageURL;
+if ( aStr[0] == '#' )
+{
+aStreamURL = aStreamURL.concat( aStr.copy( 1, 
aStr.getLength() - 1 ) );
+}
+else
+{
+aStreamURL = aStreamURL.concat( aStr );
+}
+
+uno::Any aAny;
+aAny <<= aStreamURL;
+xPropSet->setPropertyValue( OUString( 
RTL_CONSTASCII_USTRINGPARAM( "GraphicStreamURL" ) ), aAny );
 }
 
-// update stream URL for load on demand
-uno::Any aAny;
-aAny <<= aStreamURL;
-xPropSet->setPropertyValue( OUString( 
RTL_CONSTASCII_USTRINGPARAM( "GraphicStreamURL" ) ), aAny );
-
 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_TYPE, 
XML_SIMPLE );
 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_SHOW, 
@@ -1147,9 +1147,12 @@ void XMLShapeExport::ImpExportGraphicObj
"vnd.sun.star.Package:" ) );
 
-// sj: trying to preserve the filename
+// sj: trying to preserve the filename for embedded images 
which already have its stream inside the package
XML_EMBED );
 mrExport.AddAttribute( XML_NAMESPACE_XLINK, XML_ACTUATE, 
XML_ONLOAD );




svn commit: r1612804 - in /openoffice/branches/AOO410: ./ main/ main/xmloff/source/draw/shapeexport2.cxx

2014-07-23 Thread orw
Author: orw
Date: Wed Jul 23 09:15:22 2014
New Revision: 1612804

URL: http://svn.apache.org/r1612804
Log:
125289: do apply possible changed  only for embedded images 
which already have its stream inside the package
fixes also issue 125290

cherry-picked from trunk


Modified:
openoffice/branches/AOO410/   (props changed)
openoffice/branches/AOO410/main/   (props changed)
openoffice/branches/AOO410/main/xmloff/source/draw/shapeexport2.cxx

Propchange: openoffice/branches/AOO410/